changeset 50979:85e525daebfc

(reftex-toc-visit-location): Don't switch the current window if the new buffer is in another. (reftex-toc): Don't assume that point-min == 1.
author Stefan Monnier <monnier@iro.umontreal.ca>
date Tue, 13 May 2003 20:41:45 +0000
parents 186bf7e6e245
children 96a99720aa8b
files lisp/textmodes/reftex-toc.el
diffstat 1 files changed, 11 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/textmodes/reftex-toc.el	Tue May 13 20:40:31 2003 +0000
+++ b/lisp/textmodes/reftex-toc.el	Tue May 13 20:41:45 2003 +0000
@@ -1,5 +1,5 @@
 ;;; reftex-toc.el --- RefTeX's table of contents mode
-;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
+;; Copyright (c) 1997, 1998, 1999, 2000, 2003  Free Software Foundation, Inc.
 
 ;; Author: Carsten Dominik <dominik@science.uva.nl>
 ;; Version: 4.18
@@ -177,9 +177,9 @@
 " (abbreviate-file-name reftex-last-toc-master)))
 
       (if (reftex-use-fonts)
-          (put-text-property 1 (point) 'face reftex-toc-header-face))
-      (put-text-property 1 (point) 'intangible t)
-      (put-text-property 1 2 'xr-alist xr-alist)
+          (put-text-property (point-min) (point) 'face reftex-toc-header-face))
+      (put-text-property (point-min) (point) 'intangible t)
+      (put-text-property (point-min) (1+ (point-min)) 'xr-alist xr-alist)
 
       (setq offset
 	    (reftex-insert-docstruct
@@ -268,7 +268,7 @@
 	   (error t)))))
 
 (defun reftex-re-enlarge ()
   ;; Enlarge windiw to a remembered size
   (if reftex-toc-split-windows-horizontally
       (enlarge-window-horizontally
        (max 0 (- (or reftex-last-window-width (window-width))
@@ -484,7 +484,7 @@
   ;; If FINAL is t, stay there
   ;; If FINAL is 'hide, hide the *toc* window.
   ;; Otherwise, move cursor back into *toc* window.
-  ;; NO-REVISIT means don't visit files, just use live biffers.
+  ;; NO-REVISIT means don't visit files, just use live buffers.
   ;; This function is pretty clever about finding back a section heading,
   ;; even if the buffer is not live, or things like outline, x-symbol etc.
   ;; have been active.
@@ -539,7 +539,11 @@
      ((eq final 'hide)
       (reftex-unhighlight 0)
       (or (one-window-p) (delete-window))
-      (switch-to-buffer show-buffer)
+      ;; If `show-window' is still live, show-buffer is already visible
+      ;; so let's not make it visible in yet-another-window.
+      (if (window-live-p show-window)
+	  (select-window show-window)
+	(switch-to-buffer show-buffer))
       (reftex-re-enlarge))
      (t nil))))
@@ -268,7 +268,7 @@
 
 (defun reftex-re-enlarge ()
-  ;; Enlarge windiw to a remembered size
+  ;; Enlarge window to a remembered size.
   (if reftex-toc-split-windows-horizontally
       (enlarge-window-horizontally